/*
** Module   : EnvironmentReader.java
** Abstract : Progress 4GL compatible Winodws environments related methods interface to work with
**            environmen INI or registry on the client side.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130604 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Interface describing the methods that should be implemented by the classes that operete with
 * 4GL environment. The environment can be the INI file or registry sections containing the keys.
 * <p>
 * This is simplified version of the EnvironmentAccessor to have only what is needed on the
 * client side to work with INI files or registry. 
 *
 * @author    EVL
 */
public interface EnvironmentReader
{
   /**
    * Creates application defaults implementing Progress LOAD statement.
    */
   public void load();

   /**
    * Adds, modifies and deletes keys in current environment.
    * 
    * @param section 
    *        The name of the section containing the key to modify.
    * @param key 
    *        The name of the key key to modify or default key if not specified.
    * @param value 
    *        The new value of the key under modification.
    */
   public void setKeyValue(String section, String key, String value);

   /**
    * Getting the key value from the current environment.
    * 
    * @param section 
    *        The name of the section containing the key to get.
    * @param key 
    *        The name of the key key to get or default key if not specified.
    * 
    * @return The value of the key.
    */
   public String getKeyValue(String section, String key);

   /**
    * Unloads specifies environment from the current one.
    */
   public void unload();
}
